@@ -24,6 +24,8 @@ import struct
 import requests
 from io import BytesIO
 import numpy as np
+import re
+from collections import Counter
 
 def fetch_apa_data(name, version, target_column, return_X_y=False, as_frame=True):
     """_dataset fetching function_
@@ -88,9 +90,15 @@ def load_BCN_IBEX():
 def load_BCN_UK():
     return fetch_dataset('BCNDiari2021-UK')
 
+def load_BCN_cesta():
+    return fetch_dataset('BCNDiari2021-CESTA')
+
 def load_BCN_vuelos():
     return fetch_dataset('BCNDiari2021-vuelos')
 
+def load_BCN_ruido():
+    return fetch_dataset('BCNDiari2021-ruido')
+
 def load_titanic():
     return fetch_dataset('titanic')
 
@@ -113,10 +121,16 @@ def load_attrition():
     return fetch_dataset('attrition')
 
 def load_heart_failure():
-    return fetch_dataset('heart_failure')    
+    return fetch_dataset('heart_failure')   
+
+def load_darwin():
+    return fetch_dataset('DARWIN')    
+
+def load_bands():
+    return fetch_dataset('bands')   
 
 def load_arxiv():
-    bk = remotezip.RemoteZip('http://www.cs.upc.edu/~bejar/datasets/arxiv.zip', initial_buffer_size=6_000_000)
+    bk = remotezip.RemoteZip(f'{DATALINK}/arxiv.zip', initial_buffer_size=6_000_000)
     text = []
     labels = []
     for f in sorted([fn for fn in bk.namelist() if '0' in fn]):
@@ -133,7 +147,7 @@ def load_literature():
            'wells', 'lovecraft','london', 'fitzgerald']
 
 
-    bk = remotezip.RemoteZip('http://www.cs.upc.edu/~bejar/datasets/Books.zip', initial_buffer_size=6_000_000)
+    bk = remotezip.RemoteZip(f'{DATALINK}/Books.zip', initial_buffer_size=6_000_000)
     book_class = pd.read_csv(bk.open("Books/Classes.csv"), header=0, index_col=0,delimiter=',')
 
     text = []
@@ -158,7 +172,7 @@ def load_translation():
                 'dostoyevsky','verne','pushkin','dante','spinoza']
 
 
-    bk = remotezip.RemoteZip('http://www.cs.upc.edu/~bejar/datasets/Books.zip', initial_buffer_size=6_000_000)
+    bk = remotezip.RemoteZip(f'{DATALINK}/Books.zip', initial_buffer_size=6_000_000)
     book_class = pd.read_csv(bk.open("Books/Classes.csv"), header=0, index_col=0,delimiter=',')
 
     text = []
@@ -199,4 +213,65 @@ def load_MNIST(digits=(4,7,9), sel=4):
     X_test = X_test_o[np.logical_or(y_test_o == digits[0], np.logical_or(y_test_o == digits[1], y_test_o == digits[2]))]
     y_test = y_test_o[np.logical_or(y_test_o == digits[0], np.logical_or(y_test_o == digits[1], y_test_o == digits[2]))]
 
-    return X_train.reshape(-1,28*28)[::sel]/255, X_test.reshape(-1,28*28)[::sel]/255, y_train[::sel], y_test[::sel]
\ No newline at end of file
+    return X_train.reshape(-1,28*28)[::sel]/255, X_test.reshape(-1,28*28)[::sel]/255, y_train[::sel], y_test[::sel]
+
+
+def load_NASDAQ():
+    files = ['HistoricalData_GOOGLE.csv','HistoricalData_MSFT.csv',
+             'HistoricalData_AAPL.csv', 'HistoricalData_INTEL.csv',
+             'HistoricalData_AMD.csv',] 
+
+    ddata = {}
+
+
+    for f in files:
+        hcdo = pd.read_csv(f"{DATALINK}/{f}",index_col='Date').reset_index().sort_index(ascending=False).reset_index()
+        ddata[f.split('.')[0].split('_')[1]+'-P'] = hcdo['Close/Last']
+        ddata[f.split('.')[0].split('_')[1]+'-V'] = hcdo['Volume']
+        ddata[f.split('.')[0].split('_')[1]+'-GAP'] = (hcdo['High']-hcdo['Low']).abs()
+    
+    return pd.DataFrame(ddata).reset_index().drop(columns='index')
+
+def load_sentiment(nwords, train_size=0.8):
+    def tweet_to_words(raw_tweet):
+        letters_only = re.sub("[^a-zA-Z@]", " ", raw_tweet)
+        words = letters_only.lower().split()
+        meaningful_words = [w for w in words if not re.match("^[@]", w)]
+        return " ".join(meaningful_words)
+
+    bk = remotezip.RemoteZip(f'{DATALINK}/Airlines.zip', initial_buffer_size=6_000_000)
+    Tweet = pd.read_csv(bk.open("Airlines.csv"))
+    Tweet['clean_tweet'] = Tweet['text'].apply(lambda x: tweet_to_words(x))
+    Tweet['sentiment'] = Tweet['twsentiment'].apply(lambda x: 0 if x == 'negative' else 1 if x == 'positive' else 2)
+    all_text = ' '.join(Tweet['clean_tweet'])
+    words = all_text.split()
+
+    counts = Counter(words)
+    vocab = sorted(counts, key=counts.get, reverse=True)[:nwords]
+    vocab_to_int = {word: ii for ii, word in enumerate(vocab, 1)}
+
+    tweet_ints = []
+    for each in Tweet['clean_tweet']:
+        tweet_ints.append([vocab_to_int[word] for word in each.split() if word in vocab_to_int])
+
+    labels = np.array(Tweet['sentiment'])
+    tweet_len = Counter([len(x) for x in tweet_ints])
+    tweet_idx = [idx for idx, tweet in enumerate(tweet_ints) if len(tweet) > 0]
+    labels = labels[tweet_idx]
+    Tweet = Tweet.iloc[tweet_idx]
+    tweet_ints = [tweet for tweet in tweet_ints if len(tweet) > 0]
+
+    seq_len = max(tweet_len)
+    features = np.zeros((len(tweet_ints), seq_len), dtype=int)
+    for i, row in enumerate(tweet_ints):
+        features[i, -len(row):] = np.array(row)[:seq_len]
+
+    split_idx = int(len(features) * train_size)
+    X_train, val_x = features[:split_idx], features[split_idx:]
+    y_train, val_y = labels[:split_idx], labels[split_idx:]
+
+    test_idx = int(len(val_x) * 0.5)
+    X_val, X_test = val_x[:test_idx], val_x[test_idx:]
+    y_val, y_test = val_y[:test_idx], val_y[test_idx:]
+
+    return X_train, y_train, X_val, y_val, X_test, y_test
\ No newline at end of file
